==> actions-recorder-1.1.0.tgz: package/lib/app/viewer.js <==
var Color, Immutable, React, div, pre, ref, span;

React = require('react');

Color = require('color');

Immutable = require('immutable');

ref = React.DOM, div = ref.div, span = ref.span, pre = ref.pre;

module.exports = React.createClass({
  displayName: 'recorder-viewer',
  propTypes: {
    data: React.PropTypes.any,
    height: React.PropTypes.number.isRequired
  },
  getInitialState: function() {
    return {
      path: []
    };
  },
  onKeyClick: function(key) {
    return this.setState({
      path: this.state.path.concat(key)
    });
  },
  onParentKeyClick: function(key) {
    return this.setState({
      path: this.state.path.slice(0, -1).concat(key)
    });
  },
  onPathClick: function(index) {
    return this.setState({
      path: this.state.path.slice(0, index + 1)
    });
  },
  onPathRootClick: function() {
    return this.setState({
      path: []
    });
  },
  renderPath: function() {
    return div({
      style: this.stylePath()
    }, div({
      style: this.styleKey(),
      onClick: this.onPathRootClick
    }, '/'), this.state.path.map((function(_this) {
      return function(key, index) {
        var onClick;
        onClick = function() {
          return _this.onPathClick(index);
        };
        return span({
          key: key,
          style: _this.styleKey(),
          onClick: onClick
        }, key);
      };
    })(this)));
  },
  renderParentKeys: function() {
    var iterator, keys, result, value;
    keys = [];
    value = this.props.data.getIn(this.state.path.slice(0, -1));
    if (this.state.path.length > 0 && (value != null) && (value instanceof Immutable.Collection)) {
      iterator = value.keys();
      while (true) {
        result = iterator.next();
        if (result.value != null) {
          keys.push(result.value);
        }
        if (result.done) {
          break;
        }
      }
      return div({
        style: this.styleEntries()
      }, keys.map((function(_this) {
        return function(entry) {
          var onClick;
          onClick = function() {
            return _this.onParentKeyClick(entry);
          };
          return div({
            key: entry
          }, span({
            style: _this.styleKey(),
            onClick: onClick
          }, entry));
        };
      })(this)));
    } else {
      return void 0;
    }
  },
  renderKeys: function() {
    var iterator, keys, result, value;
    keys = [];
    value = this.props.data.getIn(this.state.path);
    if ((value != null) && (value instanceof Immutable.Collection)) {
      iterator = value.keys();
      while (true) {
        result = iterator.next();
        if (result.value != null) {
          keys.push(result.value);
        }
        if (result.done) {
          break;
        }
      }
      return div({
        style: this.styleEntries()
      }, keys.map((function(_this) {
        return function(entry) {
          var onClick;
          onClick = function() {
            return _this.onKeyClick(entry);
          };
          return div({
            key: entry,
            onClick: onClick
          }, span({
            style: _this.styleKey()
          }, entry));
        };
      })(this)));
    } else {
      return void 0;
    }
  },
  renderValue: function() {
    var value;
    value = this.props.data.getIn(this.state.path);
    return pre({
      style: this.styleValue()
    }, JSON.stringify(value, null, 2));
  },
  render: function() {
    return div({
      style: this.styleRoot()
    }, this.renderPath(), this.props.data instanceof Immutable.Collection ? div({
      style: this.styleTable()
    }, this.renderParentKeys(), this.renderKeys(), this.renderValue()) : pre({
      style: this.styleValue()
    }, this.props.data));
  },
  styleRoot: function() {
    return {
      flex: 1,
      height: this.props.height
    };
  },
  styleTable: function() {
    return {
      display: 'flex',
      flexDirection: 'row',
      flex: 1,
      overflowY: 'auto',
      height: this.props.height - 70
    };
  },
  styleEntries: function() {
    return {
      width: '300px',
      height: this.props.height - 70,
      overflowY: 'auto',
      overflowX: 'visible'
    };
  },
  stylePath: function() {
    return {
      margin: '20px 0'
    };
  },
  styleKey: function() {
    return {
      backgroundColor: Color().hsl(0, 0, 90, 0.2).hslString(),
      padding: '0 10px',
      lineHeight: '24px',
      fontSize: '14px',
      display: 'inline-block',
      cursor: 'pointer',
      marginRight: '10px',
      marginBottom: '6px'
    };
  },
  styleValue: function() {
    return {
      flex: 1,
      margin: 0,
      overflowY: 'auto',
      height: this.props.height - 70
    };
  }
});

==> actions-recorder-1.1.2.tgz: package/lib/app/viewer.js <==
var Color, Immutable, React, div, getKeyFromCollection, pre, ref, span;

React = require('react');

Color = require('color');

Immutable = require('immutable');

ref = React.DOM, div = ref.div, span = ref.span, pre = ref.pre;

getKeyFromCollection = function(value) {
  var iterator, keys, result;
  keys = [];
  iterator = value.keys();
  while (true) {
    result = iterator.next();
    if (result.value != null) {
      keys.push(result.value);
    }
    if (result.done) {
      break;
    }
  }
  if (Immutable.Map.isMap(value)) {
    return keys.sort();
  } else {
    return keys;
  }
};

module.exports = React.createClass({
  displayName: 'recorder-viewer',
  propTypes: {
    data: React.PropTypes.any,
    height: React.PropTypes.number.isRequired
  },
  getInitialState: function() {
    return {
      path: []
    };
  },
  onKeyClick: function(key) {
    return this.setState({
      path: this.state.path.concat(key)
    });
  },
  onParentKeyClick: function(key) {
    return this.setState({
      path: this.state.path.slice(0, -1).concat(key)
    });
  },
  onPathClick: function(index) {
    return this.setState({
      path: this.state.path.slice(0, index + 1)
    });
  },
  onPathRootClick: function() {
    return this.setState({
      path: []
    });
  },
  renderPath: function() {
    return div({
      style: this.stylePath()
    }, div({
      style: this.styleKey(),
      onClick: this.onPathRootClick
    }, '/'), this.state.path.map((function(_this) {
      return function(key, index) {
        var onClick;
        onClick = function() {
          return _this.onPathClick(index);
        };
        return span({
          key: key,
          style: _this.styleKey(),
          onClick: onClick
        }, key);
      };
    })(this)));
  },
  renderParentKeys: function() {
    var keys, value;
    value = this.props.data.getIn(this.state.path.slice(0, -1));
    if (this.state.path.length > 0 && (value != null) && (value instanceof Immutable.Collection)) {
      keys = getKeyFromCollection(value);
      return div({
        style: this.styleEntries()
      }, keys.map((function(_this) {
        return function(entry) {
          var onClick;
          onClick = function() {
            return _this.onParentKeyClick(entry);
          };
          return div({
            key: entry
          }, span({
            style: _this.styleKey(),
            onClick: onClick
          }, entry));
        };
      })(this)));
    }
  },
  renderKeys: function() {
    var keys, value;
    value = this.props.data.getIn(this.state.path);
    if ((value != null) && (value instanceof Immutable.Collection)) {
      keys = getKeyFromCollection(value);
      return div({
        style: this.styleEntries()
      }, keys.map((function(_this) {
        return function(entry) {
          var onClick;
          onClick = function() {
            return _this.onKeyClick(entry);
          };
          return div({
            key: entry,
            onClick: onClick
          }, span({
            style: _this.styleKey()
          }, entry));
        };
      })(this)));
    }
  },
  renderValue: function() {
    var value;
    value = this.props.data.getIn(this.state.path);
    return pre({
      style: this.styleValue()
    }, JSON.stringify(value, null, 2));
  },
  render: function() {
    return div({
      style: this.styleRoot()
    }, this.renderPath(), this.props.data instanceof Immutable.Collection ? div({
      style: this.styleTable()
    }, this.renderParentKeys(), this.renderKeys(), this.renderValue()) : pre({
      style: this.styleValue()
    }, this.props.data));
  },
  styleRoot: function() {
    return {
      flex: 1,
      height: this.props.height
    };
  },
  styleTable: function() {
    return {
      display: 'flex',
      flexDirection: 'row',
      flex: 1,
      overflowY: 'auto',
      height: this.props.height - 70
    };
  },
  styleEntries: function() {
    return {
      width: 'auto',
      height: this.props.height - 70,
      overflowY: 'auto',
      overflowX: 'visible',
      paddingRight: '40px',
      paddingTop: '100px',
      paddingBottom: '100px'
    };
  },
  stylePath: function() {
    return {
      margin: '20px 0'
    };
  },
  styleKey: function() {
    return {
      backgroundColor: Color().hsl(0, 0, 90, 0.2).hslString(),
      padding: '0 10px',
      lineHeight: '24px',
      fontSize: '12px',
      display: 'inline-block',
      cursor: 'pointer',
      marginRight: '10px',
      marginBottom: '6px'
    };
  },
  styleValue: function() {
    return {
      flex: 1,
      margin: 0,
      overflowY: 'auto',
      height: this.props.height - 70,
      lineHeight: '21px',
      fontSize: '12px',
      fontFamily: 'Menlo, Consolas, Ubuntu Mono, monospace',
      paddingTop: '100px',
      paddingBottom: '100px'
    };
  }
});
